{***************************************************************
 *
 * Unit Name : GrupareDlg
 * Purpose   :
 * Author    : Eugen Mihailescu
 * Company   : EM Quicksoft Romania SRL
 * Copyright : 1998,2002  All rights reserved.
 * Web Site  : http://www.em-quicksoft.com
 * Support   : support@em-quicksoft.com
 * History   : 03/17/2000
 *
 * Disclaimer: The objectives of this program is only educational.
 *             You MUST NOT use it without getting any material benefit on it
 *             You have the right to share this code with others without removing
 *             the copyright and/or disclaimer notice.
 *             You are allowed to include its code in your application
 *             only if it was designed for non commercial purpose,
 *             otherwise we claim $10 for each copy of your
 *             application which contains this code inside.
 ****************************************************************}

Unit GrupareDlg;

Interface

Uses
  Windows,
  Messages,
  SysUtils,
  Classes,
  Graphics,
  Controls,
  Forms,
  Dialogs,
  FileCtrl,
  StdCtrls,
  DBTables,
  Db,
  ComCtrls,
  IniFiles,
  ExtCtrls;

Type
  TfrmGrupare = Class(TForm)
    Label1: TLabel;
    edtDir: TEdit;
    Button1: TButton;
    Source: TTable;
    Destination: TTable;
    BatchMove1: TBatchMove;
    Label2: TLabel;
    edtFile: TEdit;
    Button2: TButton;
    SaveDialog1: TSaveDialog;
    Button3: TButton;
    Label3: TLabel;
    edtPrefix: TEdit;
    Button4: TButton;
    StatusBar1: TStatusBar;
    Timer1: TTimer;
    Label4: TLabel;
    lblTotal: TLabel;
    Procedure Button1Click(Sender: TObject);
    Procedure Button2Click(Sender: TObject);
    Procedure FormShow(Sender: TObject);
    Procedure FormClose(Sender: TObject; Var Action: TCloseAction);
    Procedure Button3Click(Sender: TObject);
    Procedure Timer1Timer(Sender: TObject);
  private
    Procedure LoadSettings;
    Procedure SaveSettings;
    Procedure MoveData(FromDB, ToDB: String);
    Procedure Execute;
    Procedure EnableControls(Value: Boolean);
  public
    TotalRec: Integer;
  End;

Var
  frmGrupare        : TfrmGrupare;

Implementation

{$R *.DFM}
//******************* SlashSep *************************

Function SlashSep(Const Path, S: String): String;
Begin
  If AnsiLastChar(Path)^ <> '\' Then
    Result := Path + '\' + S
  Else
    Result := Path + S;
End;
//******************* TfrmGrupare.Button1Click *************************

Procedure TfrmGrupare.Button1Click(Sender: TObject);
Var
  Dir               : String;
Begin
  If SelectDirectory('Selectati folderul unde sunt datele', '', Dir) Then
    edtDir.Text := SlashSep(Dir, '');
End;
//******************* TfrmGrupare.Button2Click *************************

Procedure TfrmGrupare.Button2Click(Sender: TObject);
Begin
  If SaveDialog1.Execute Then
    edtFile.Text := SaveDialog1.FileName;
End;
//******************* TfrmGrupare.LoadSettings *************************

Procedure TfrmGrupare.LoadSettings;
Var
  F                 : TIniFile;
Begin
  F := TIniFile.Create(ExtractFilePath(Application.ExeName) + 'Settings.ini');
  Try
    edtDir.Text := F.ReadString('Path', 'FilePath', '');
    edtFile.Text := F.ReadString('Path', 'NewFileName', '');
    edtPrefix.Text := F.ReadString('Path', 'FilePrefix', '');
  Finally
    F.Free;
  End;
End;
//******************* TfrmGrupare.SaveSettings *************************

Procedure TfrmGrupare.SaveSettings;
Var
  F                 : TIniFile;
Begin
  F := TIniFile.Create(ExtractFilePath(Application.ExeName) + 'Settings.ini');
  Try
    F.WriteString('Path', 'FilePath', edtDir.Text);
    F.WriteString('Path', 'NewFileName', edtFile.Text);
    F.WriteString('Path', 'FilePrefix', edtPrefix.Text);
  Finally
    F.Free;
  End;
End;
//******************* TfrmGrupare.FormShow *************************

Procedure TfrmGrupare.FormShow(Sender: TObject);
Begin
  LoadSettings;
End;
//******************* TfrmGrupare.FormClose *************************

Procedure TfrmGrupare.FormClose(Sender: TObject; Var Action: TCloseAction);
Begin
  SaveSettings;
  Action := caFree;
End;
//******************* TfrmGrupare.MoveData *************************

Procedure TfrmGrupare.MoveData(FromDB, ToDB: String);
Begin
  Source.Active := False;
  Destination.Active := False;
  Source.TableName := FromDB;
  Destination.TableName := ToDB;
  If Not fileexists(ToDB) Then
    BatchMove1.Mode := batCopy
  Else
    BatchMove1.Mode := batAppend;
  BatchMove1.Execute;
End;
//******************* TfrmGrupare.Execute *************************

Procedure TfrmGrupare.Execute;
Var
  R                 : TSearchRec;
  Found             : Integer;
Begin
  TotalRec := 0;
  Found := FindFirst(SlashSep(edtDir.Text, '') + edtPrefix.Text + '*.db', faAnyFile, R);
  While Found = 0 Do
    Begin
      StatusBar1.SimpleText := Format('Adaugare date din fisierul %s...', [R.Name]);
      Application.ProcessMessages;
      MoveData(SlashSep(edtDir.Text, '') + R.Name, edtFile.Text);
      TotalRec := TotalRec + BatchMove1.MovedCount;
      Found := FindNext(R);
    End;
End;
//******************* TfrmGrupare.Button3Click *************************

Procedure TfrmGrupare.Button3Click(Sender: TObject);
Begin
  EnableControls(False);
  Try
    Execute;
  Except
    On E: Exception Do MessageDlg(E.Message, mtError, [mbOK], 0);
  End;
  EnableControls(True);
End;
//******************* TfrmGrupare.EnableControls *************************

Procedure TfrmGrupare.EnableControls(Value: Boolean);
Var
  I                 : Integer;
Begin
  For I := 0 To ControlCount - 1 Do
    If (Controls[I] Is TEdit) Then
      (Controls[I] As TEdit).Enabled := Value
    Else
      If (Controls[I] Is TButton) Then
      (Controls[I] As TButton).Enabled := Value;
End;
//******************* TfrmGrupare.Timer1Timer *************************

Procedure TfrmGrupare.Timer1Timer(Sender: TObject);
Begin
  lblTotal.Caption := Format('%d inregistrari', [TotalRec]);
  Application.ProcessMessages;
End;

End.

